@@ -14,8 +14,7 @@ class SMTPMailTransportPlugin : public MailTransport::TransportAbstractPlugin
 {
     Q_OBJECT
 public:
-    explicit SMTPMailTransportPlugin(QObject *parent = nullptr, const QList<QVariant> & =
-    {
+    explicit SMTPMailTransportPlugin(QObject *parent = nullptr, const QList<QVariant> & = {
     });
     ~SMTPMailTransportPlugin() override;
 
