@@ -9,7 +9,6 @@
 #include "mailtransportplugin_akonadi_debug.h"
 #include <KPluginFactory>
 #include <AkonadiCore/AgentManager>
-#include <MailTransport/TransportAbstractPlugin>
 #include <AkonadiCore/AgentInstanceCreateJob>
 #include <MailTransport/Transport>
 
@@ -85,7 +84,7 @@ MailTransport::TransportJob *AkonadiMailTransportPlugin::createTransportJob(Mail
 
 void AkonadiMailTransportPlugin::initializeTransport(MailTransport::Transport *t, const QString &identifier)
 {
-    AgentInstanceCreateJob *cjob = new AgentInstanceCreateJob(identifier);
+    auto *cjob = new AgentInstanceCreateJob(identifier);
     if (!cjob->exec()) {
         qCWarning(MAILTRANSPORT_AKONADI_LOG) << "Failed to create agent instance of type" << identifier;
         return;
