@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
   SPDX-FileContributor: Tobias Koenig <tokoe@kdab.com>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
@@ -17,7 +17,6 @@ class SentActionAttribute::Action::Private : public QSharedData
 {
 public:
     Private()
-        : mType(Invalid)
     {
     }
 
@@ -28,7 +27,7 @@ public:
         mValue = other.mValue;
     }
 
-    Type mType;
+    Type mType = Invalid;
     QVariant mValue;
 };
 
@@ -105,7 +104,7 @@ SentActionAttribute::Action::List SentActionAttribute::actions() const
 
 SentActionAttribute *SentActionAttribute::clone() const
 {
-    SentActionAttribute *attribute = new SentActionAttribute;
+    auto *attribute = new SentActionAttribute;
     attribute->d->mActions = d->mActions;
 
     return attribute;
